Test and documentation utilities
********************************

.. automodule:: genno.testing
   :members:

.. automodule:: genno.testing.jupyter
   :members:

.. automodule:: genno.compat.sphinx

.. automodule:: genno.compat.sphinx.autodoc_operator
   :members:

.. automodule:: genno.compat.sphinx.rewrite_refs
   :members:
